from .loader import load_entry_points


main = load_entry_points()
# main object is called by the console script.
